@@ -41,13 +41,28 @@ class UptimeRobot(object):
             return False
         
         
-    def getMonitors(self):
-        """ 
+    def getMonitors(self, response_times=0, logs=0, uptime_ratio=''):
+        """
         Returns status and response payload for all known monitors.
         """
         url = self.baseUrl
         url += "getMonitors?apiKey=%s" % (self.apiKey)
         url += "&noJsonCallback=1&format=json"
+        # responseTimes - optional (defines if the response time data of each
+        # monitor will be returned. Should be set to 1 for getting them. Default
+        # is 0)
+        if response_times:
+            url += "&responseTimes=1"
+        # logs - optional (defines if the logs of each monitor will be returned.
+        # Should be set to 1 for getting the logs. Default is 0)
+        if logs:
+            url += '&logs=1'
+        # customUptimeRatio - optional (defines the number of days to calculate
+        # the uptime ratio(s) for. Ex: customUptimeRatio=7-30-45 to get the
+        # uptime ratios for those periods)
+        if uptime_ratio:
+            url += '&customUptimeRatio=%s' % uptime_ratio
+
         return self.requestApi(url)
         
         
@@ -131,5 +146,5 @@ if __name__ == "__main__":
         print("A new Monitor was installed successfully")
         sys.exit(0)
     else:
-        print("There were some Errors, mayme the Monitor already exists?")
+        print("There were some Errors, maybe the Monitor already exists?")
         sys.exit(1)
